#include <string.h>
#include <sys/types.h>
#include <dirent.h>
#include <unistd.h>
#include <stdlib.h>
#include <sys/stat.h>
#include <fcntl.h>
#include "iolib.h"
const char *progname = "envdir";
const char *proghelp =
	"Usage: envdir [OPTIONS] dir command ...\n"
	"Run a command with environment variables set from a directory.\n\n";
#include "freedt.h"

int main(int argc, char **argv) {
	DIR *dir;

	istdinit();

	get_default_args(argc, argv);
	if ((argc - optind) < 2)
		help();

	dir = opendir(argv[optind]);
	if (!dir)
		die("unable to open directory");

	while (1) {
		struct dirent *e = readdir(dir);
		buffer filename = BUFFER, line = BUFFER;
		io *f;
		int rc;

		if (!e)
			break;

		if (strcmp(e->d_name, ".") == 0
			|| strcmp(e->d_name, "..") == 0)
			continue;

		bformat(&filename, "@c/@c", argv[optind], e->d_name);

		f = iopenrb(bstr(&filename));
		if (!f)
			die2(bstr(&filename), "unable to open file");
		rc = breadline(&line, f);
		if (rc < 0)
			die("read failed");
		if (rc == 0) {
			unsetenv(e->d_name);
		} else {
			btrimr(&line);
			breplacec(&line, '\n', '\0');

			if (fdt_setenv(e->d_name, bstr(&line)) < 0)
				die("unable to set variable");
		}
		iclose(f);
		bfree(&filename);
		bfree(&line);
	}

	++optind;
	execvp(argv[optind], &argv[optind]);
	die2(argv[optind], "unable to exec");

	return 0; /* NOTREACHED */
}

